@@ -383,7 +383,7 @@ namespace loops {
 			size_t start = 0;
 			for (int i = 0; i < nThreads - 1; ++i, start += chunkSize) {
         results.emplace_back(
-  					pool.enqueue([=] {
+  					pool.enqueue([begin, start, function, this] {
 							std::for_each(
 								begin + start,
 								begin + start + chunkSize,
